summaryrefslogtreecommitdiff
path: root/lib/sqlalchemy/orm
diff options
context:
space:
mode:
Diffstat (limited to 'lib/sqlalchemy/orm')
-rw-r--r--lib/sqlalchemy/orm/mapper.py12
-rw-r--r--lib/sqlalchemy/orm/state.py2
2 files changed, 7 insertions, 7 deletions
diff --git a/lib/sqlalchemy/orm/state.py b/lib/sqlalchemy/orm/state.py
index 22ad06f13..0f60c6712 100644
--- a/lib/sqlalchemy/orm/state.py
+++ b/lib/sqlalchemy/orm/state.py
@@ -49,7 +49,7 @@ class InstanceState(interfaces._InspectionAttr):
self.committed_state = {}
@util.memoized_property
- def attr(self):
+ def attrs(self):
"""Return a namespace representing each attribute on
the mapped object, including its current value
and history.
diff --git a/lib/sqlalchemy/orm/mapper.py b/lib/sqlalchemy/orm/mapper.py
index 45124127a..4269e332f 100644
--- a/lib/sqlalchemy/orm/mapper.py
+++ b/lib/sqlalchemy/orm/mapper.py
@@ -1492,14 +1492,14 @@ class Mapper(_InspectionAttr):
yield c
@util.memoized_property
- def attr(self):
+ def attrs(self):
"""A namespace of all :class:`.MapperProperty` objects
associated this mapper.
This is an object that provides each property based on
its key name. For instance, the mapper for a
``User`` class which has ``User.name`` attribute would
provide ``mapper.attr.name``, which would be the
:class:`.ColumnProperty` representing the ``name``
column. The namespace object can also be iterated,
which would yield each :class:`.MapperProperty`.
@@ -1522,7 +1522,7 @@ class Mapper(_InspectionAttr):
See also:
- :attr:`.Mapper.attr` - namespace of all :class:`.MapperProperty`
+ :attr:`.Mapper.attrs` - namespace of all :class:`.MapperProperty`
objects.
"""
@@ -1535,7 +1535,7 @@ class Mapper(_InspectionAttr):
See also:
- :attr:`.Mapper.attr` - namespace of all :class:`.MapperProperty`
+ :attr:`.Mapper.attrs` - namespace of all :class:`.MapperProperty`
objects.
"""
@@ -1548,7 +1548,7 @@ class Mapper(_InspectionAttr):
See also:
- :attr:`.Mapper.attr` - namespace of all :class:`.MapperProperty`
+ :attr:`.Mapper.attrs` - namespace of all :class:`.MapperProperty`
objects.
"""
@@ -1561,7 +1561,7 @@ class Mapper(_InspectionAttr):
See also:
- :attr:`.Mapper.attr` - namespace of all :class:`.MapperProperty`
+ :attr:`.Mapper.attrs` - namespace of all :class:`.MapperProperty`
objects.
"""
@@ -1492,14 +1492,14 @@ class Mapper(_InspectionAttr):
its key name. For instance, the mapper for a
``User`` class which has ``User.name`` attribute would
- provide ``mapper.attr.name``, which would be the
+ provide ``mapper.attrs.name``, which would be the
:class:`.ColumnProperty` representing the ``name``
column. The namespace object can also be iterated,